TxConfig

Struct TxConfig 

#[non_exhaustive]
pub struct TxConfig { /* private fields */ }
UHCI Tx Configuration

Implementations

Source

impl TxConfig

pub fn with_idle_eof(self, idle_eof: bool) -> Self

Assign the given value to the idle_eof field.

pub fn idle_eof(&self) -> bool

If this is set to true UHCI will end the payload receiving process when UART has been in idle state.

pub fn with_len_eof(self, len_eof: bool) -> Self

Assign the given value to the len_eof field.

pub fn len_eof(&self) -> bool

If this is set to true UHCI decoder receiving payload data ends when the receiving byte count has reached the specified value (in len_eof). If this is set to false UHCI decoder receiving payload data is end when 0xc0 is received.